Crate phf_mut [−] [src]
Perfectly hashed mutable containers.
Structs
| KeyIter |
Iterator over the domain of a |
| Map |
A mutable, perfectly-hashed map. Note that a |
| MapIter | |
| MapIterMut | |
| Set |
A mutable, perfectly-hashed set. Note that a small domain is recommended.
For sparse sets, you might prefer |
| SetIter |
Traits
| HashInverse |
Inverse operation of the perfect hash function. This is necessary for all operations that generate key values, for example iteration. |
| PerfectHash |
The perfect hash function to be used in all further constructions. |